Lernmatrix structure for conditional learning and recall, with application in supervised classification.

# Installation

```
pip3 install lernmatrix-learner
```

## From source code

```
git clone https://github.com/erickorsi/lernmatrix-learner
```

## Use

```python
from lernmatrix import Lernmatrix
```

# The Lernmatrix

The Steinbuch Lernmatrix is a mathematical model and early artificial neural network created by Karl Steinbuch around 1960 for simulating associative memory. This model has many parallels with the auto-associative memory of the human hippocampus, in a simplified manner.